R/methylationGLMM_T1T2_steps.R
annotateMethylationGLMM_T1T2Summaries.RdMerge phenotype-specific longitudinal summary tables with probe annotation metadata and return a single annotated result table.
annotateMethylationGLMM_T1T2Summaries(
modelSummaries,
annotationObject,
annotationCols = c("Name", "chr", "pos", "UCSC_RefGene_Group", "UCSC_RefGene_Name",
"Relation_to_Island", "GencodeV41_Group"),
verbose = FALSE,
logs = FALSE,
log_dir = NULL,
log_file = "log_methylationGLMM_T1T2.txt"
)Object returned by
summarizeMethylationGLMM_T1T2Models() or a named list of summary data
frames.
Character package/object name, annotation data frame,
or annotation object understood by minfi::getAnnotation().
Character vector or comma-separated string of annotation columns to append.
Logical. If TRUE, emit progress messages with message().
Logical. If TRUE, write the same messages to a log file.
Character or NULL. Directory used for the log file when
logs = TRUE.
Character. File name used when logs = TRUE.
A list with class "dnaEPICO_methylationGLMM_T1T2_annotation"
containing the annotated summary table and any requested annotation columns
that were unavailable in the chosen annotation object.
ex <- dnaEPICO:::exampleMethylationGLMMStateDnaEpico()
annotation_data <- annotateMethylationGLMM_T1T2Summaries(
modelSummaries = ex$modelSummaries,
annotationObject = ex$annotationData,
annotationCols = "Name,chr,pos",
verbose = FALSE,
logs = FALSE
)
names(annotation_data)
#> [1] "data" "annotationColumnsUsed" "missingAnnotationCols"