Collect the raw coefficient tables for CpGs whose phenotype main effect or interaction p-value passes the requested threshold.

collectSignificantCpGsMethylationGLM_T1(
  modelResults,
  pvalThreshold = 0.05,
  interactionTerm = NULL,
  verbose = FALSE,
  logs = FALSE,
  log_dir = NULL,
  log_file = "log_methylationGLM_T1.txt"
)

Arguments

modelResults

Object returned by fitMethylationGLM_T1Models().

pvalThreshold

Numeric. Threshold applied to phenotype main-effect or interaction p-values.

interactionTerm

Character or NULL. Optional interaction term.

verbose

Logical. If TRUE, emit progress messages with message().

logs

Logical. If TRUE, write the same messages to a log file.

log_dir

Character or NULL. Directory used for the log file when logs = TRUE.

log_file

Character. File name used when logs = TRUE.

Value

A list with class "dnaEPICO_methylationGLM_T1_significant_cpgs".

Examples

ex <- dnaEPICO:::exampleMethylationGLMStateDnaEpico()
significant_cpgs <- collectSignificantCpGsMethylationGLM_T1(
  modelResults = ex$modelResults,
  pvalThreshold = 1,
  verbose = FALSE,
  logs = FALSE
)
names(significant_cpgs)
#> [1] "status"