Call ENmix::plotCtrl() for a supplied RGSet. This function only writes files when output_dir is provided because ENmix::plotCtrl() produces JPG files on disk rather than returning a plot object.

plotCtrlMinfiEwasWater(
  RGSet,
  output_dir = NULL,
  verbose = FALSE,
  logs = FALSE,
  log_dir = NULL,
  log_file = "log_plotCtrlMinfiEwasWater.txt"
)

Arguments

RGSet

An RGChannelSet.

output_dir

Character or NULL. Directory where ENmix control JPG files should be written. If NULL, the function returns without writing files.

verbose

Logical. If TRUE, emit progress messages with message().

logs

Logical. If TRUE, write the same messages to a log file.

log_dir

Character or NULL. Directory used for the log file when logs = TRUE.

log_file

Character. File name used when logs = TRUE.

Value

Invisibly returns output_dir.

Examples

ex <- dnaEPICO:::exampleMinfiBaseDataDnaEpico()
output_dir <- file.path(tempdir(), "enmix-control-plots")
plotCtrlMinfiEwasWater(
  RGSet = ex$RGSet,
  output_dir = output_dir,
  verbose = FALSE,
  logs = FALSE
)
#> Plotting  STAINING .jpg 
#> Plotting  EXTENSION .jpg 
#> Plotting  HYBRIDIZATION .jpg 
#> Plotting  TARGET_REMOVAL .jpg 
#> Plotting  BISULFITE_CONVERSION_I .jpg 
#> Plotting  BISULFITE_CONVERSION_II .jpg 
#> Plotting  SPECIFICITY_I .jpg 
#> Plotting  SPECIFICITY_II .jpg 
#> Plotting  NON-POLYMORPHIC .jpg 
#> Plotting  NEGATIVE .jpg 
#> Plotting  NORM_A .jpg 
#> Plotting  NORM_C .jpg 
#> Plotting  NORM_G .jpg 
#> Plotting  NORM_T .jpg 
#> Plotting  NORM_ACGT .jpg 
dir.exists(output_dir)
#> [1] TRUE