Plot multidimensional scaling or density summaries from final metrics

plotMetricsMinfiEwasWater(
  metricsData,
  targets,
  plot = c("mds", "density"),
  plotGroupVar = "Sex",
  sexColumn = "Sex",
  display = FALSE,
  file = NULL,
  width = 2000L,
  height = 1000L,
  res = 150L,
  verbose = FALSE,
  logs = FALSE,
  log_dir = NULL,
  log_file = "log_plotMetricsMinfiEwasWater.txt"
)

Arguments

metricsData

Object returned by extractMetricsMinfiEwasWater().

targets

Filtered phenotype data aligned with metricsData.

plot

Character. Plot type: "mds" or "density".

plotGroupVar

Character. Phenotype column used for the main grouping.

sexColumn

Character. Phenotype column used for the sex grouping in the MDS plot.

display

Logical. If TRUE, draw the plot on the active graphics device.

file

Character or NULL. TIFF file written when supplied.

width

Integer. TIFF width in pixels when file is supplied.

height

Integer. TIFF height in pixels when file is supplied.

res

Integer. TIFF resolution in DPI when file is supplied.

verbose

Logical. If TRUE, emit progress messages with message().

logs

Logical. If TRUE, write the same messages to a log file.

log_dir

Character or NULL. Directory used for the log file when logs = TRUE.

log_file

Character. File name used when logs = TRUE.

Value

Invisibly returns the saved TIFF path when file is supplied, otherwise NULL.

Examples

ex <- dnaEPICO:::exampleMinfiMetricsStateDnaEpico()
plotMetricsMinfiEwasWater(
  metricsData = ex$metricsData,
  targets = ex$targets,
  plot = "density",
  plotGroupVar = "Sex",
  sexColumn = "Sex",
  display = FALSE,
  verbose = FALSE,
  logs = FALSE
)