Draw the pre-normalization beta density plot from a raw minfi object and a grouping variable in the phenotype table.

plotRawDensityMinfiEwasWater(
  rawData,
  targets,
  plotGroupVar = "Sex",
  display = FALSE,
  file = NULL,
  width = 2000L,
  height = 1000L,
  res = 150L,
  verbose = FALSE,
  logs = FALSE,
  log_dir = NULL,
  log_file = "log_plotRawDensityMinfiEwasWater.txt"
)

Arguments

rawData

Object returned by buildRawMinfiEwasWater().

targets

Filtered phenotype data aligned with rawData.

plotGroupVar

Character. Phenotype column used to group samples in the density plot.

display

Logical. If TRUE, draw the plot on the active graphics device.

file

Character or NULL. TIFF file written when supplied.

width

Integer. TIFF width in pixels when file is supplied.

height

Integer. TIFF height in pixels when file is supplied.

res

Integer. TIFF resolution in DPI when file is supplied.

verbose

Logical. If TRUE, emit progress messages with message().

logs

Logical. If TRUE, write the same messages to a log file.

log_dir

Character or NULL. Directory used for the log file when logs = TRUE.

log_file

Character. File name used when logs = TRUE.

Value

Invisibly returns the saved TIFF path when file is supplied, otherwise NULL.

Examples

ex <- dnaEPICO:::exampleMinfiMetricsStateDnaEpico()
plotRawDensityMinfiEwasWater(
  rawData = ex$rawData,
  targets = ex$targets,
  plotGroupVar = "Sex",
  display = FALSE,
  verbose = FALSE,
  logs = FALSE
)