Objects of class "dnaEPICO_methylationLME" are list-based results returned by methylationLME(). They collect the prepared longitudinal analysis table, fitted mixed models, summaries, diagnostics, annotations, and optional saved files.

Structure

preparedData

Object returned by prepareMethylationLMEData().

modelFits

Object returned by fitMethylationLMEModels().

modelSummaries

Object returned by summarizeMethylationLMEModels().

significantInteractions

Object returned by collectSignificantInteractionsMethylationLME().

diagnosticPlots

Object returned by plotMethylationLMEDiagnostics().

annotation

Object returned by annotateMethylationLMESummaries().

savedFiles

Object returned by writeMethylationLMEOutputs() when saveOutputs = TRUE, otherwise NULL.

See also