Generate a DNA methylation PDF report

dnamReport(
  output = "DNAm_Report.pdf",
  outputDir = "reports",
  qcDir = "figures/preprocessingMinfiEwasWater/enMix",
  preprocessingDir = "figures/preprocessingMinfiEwasWater/qc",
  postprocessingDir = "figures/preprocessingMinfiEwasWater/metrics",
  svaDir = "figures/svaEnmix/sva",
  glmDir = "figures/methylationGLM_T1",
  glmmDir = "figures/methylationGLMM_T1T2",
  figDir = "reports/figures",
  reportTitle = "DNA methylation",
  author = "School of Biomedical Sciences",
  date = format(Sys.Date(), "%B %d, %Y")
)

Arguments

output

Character. Name of the output PDF file.

outputDir

Character. Directory where the report will be saved.

qcDir

Character. Directory containing ENmix QC figures.

preprocessingDir

Character. Directory containing preprocessing QC figures.

postprocessingDir

Character. Directory containing postprocessing metric figures.

svaDir

Character. Directory containing SVA figures.

glmDir

Character. Directory containing GLM figures.

glmmDir

Character. Directory containing GLMM figures.

figDir

Character. Directory where figures will be copied for the report.

reportTitle

Character. Title of the report.

author

Character. Author name displayed in the report.

date

Character. Report date.

Value

Invisibly returns NULL. This function is called for its side effect of generating a PDF report and associated output files.

Examples

tmp <- tempdir()
stopifnot(dir.exists(tmp))

# \donttest{
dnamReport(
  output = "DNAm_Report.pdf",
  outputDir = "reports",
  qcDir = "figures/preprocessingMinfiEwasWater/enMix",
  preprocessingDir = "figures/preprocessingMinfiEwasWater/qc",
  postprocessingDir = "figures/preprocessingMinfiEwasWater/metrics",
  svaDir = "figures/svaEnmix/sva",
  glmDir = "figures/methylationGLM_T1",
  glmmDir = "figures/methylationGLMM_T1T2",
  figDir = "reports/figures",
  reportTitle = "DNA methylation analysis",
  author = "School of Biomedical Sciences",
  date = format(Sys.Date(), "%B %d, %Y")
)
#> 
#> 
#> processing file: DNAm.Rmd
#> 1/17                  
#> 2/17 [setup]          
#> 3/17                  
#> 4/17 [unnamed-chunk-1]
#> 5/17                  
#> 6/17 [unnamed-chunk-2]
#> 7/17                  
#> 8/17 [unnamed-chunk-3]
#> 9/17                  
#> 10/17 [unnamed-chunk-4]
#> 11/17                  
#> 12/17 [unnamed-chunk-5]
#> 13/17                  
#> 14/17 [unnamed-chunk-6]
#> 15/17                  
#> 16/17 [unnamed-chunk-7]
#> 17/17                  
#> output file: DNAm.knit.md
#> /usr/bin/pandoc +RTS -K512m -RTS DNAm.knit.md --to latex --from markdown+autolink_bare_uris+tex_math_single_backslash --output /__w/dnaEPICO/dnaEPICO/docs/reference/reports/DNAm_Report.tex --lua-filter /usr/local/lib/R/site-library/rmarkdown/rmarkdown/lua/pagebreak.lua --lua-filter /usr/local/lib/R/site-library/rmarkdown/rmarkdown/lua/latex-div.lua --embed-resources --standalone --table-of-contents --toc-depth 2 --number-sections --highlight-style tango --pdf-engine pdflatex --variable graphics --extract-media /__w/dnaEPICO/dnaEPICO/docs/reference/reports/DNAm_Report_files --include-in-header /tmp/Rtmp8H0D9X/rmarkdown-stra9937159292e.html 
#> 
#> Output created: reports/DNAm_Report.pdf
# }