R/preprocessingMinfiEwasWater_steps.R
filterSamplesMinfiEwasWater.RdRemove failed samples identified during sample assessment and return the
filtered RGChannelSet together with the aligned phenotype table.
filterSamplesMinfiEwasWater(
RGSet,
targets,
failedSamples = character(0),
SampleID = "Sample_Name",
verbose = FALSE,
logs = FALSE,
log_dir = NULL,
log_file = "log_filterSamplesMinfiEwasWater.txt"
)An RGChannelSet.
Data frame containing phenotype information.
Character vector of sample identifiers to remove.
Character. Name of the sample identifier column in targets.
Logical. If TRUE, emit progress messages with message().
Logical. If TRUE, write the same messages to a log file.
Character or NULL. Directory used for the log file when
logs = TRUE.
Character. File name used when logs = TRUE.
A list with class "dnaEPICO_minfiEwasWater_samples" containing the
filtered RGSet, aligned phenotype table, and failed sample identifiers.
ex <- dnaEPICO:::exampleMinfiBaseDataDnaEpico()
filtered_samples <- filterSamplesMinfiEwasWater(
RGSet = ex$RGSet,
targets = ex$targets,
failedSamples = ex$targets$Sample_Name[1],
SampleID = "Sample_Name",
verbose = FALSE,
logs = FALSE
)
nrow(filtered_samples$targets)
#> [1] 4