R/methylationGLM_T1_steps.R
plotMethylationGLM_T1Distributions.RdCreate phenotype, factor-variable, and numeric-covariate distribution plots
from the object returned by prepareMethylationGLM_T1Data().
plotMethylationGLM_T1Distributions(
preparedData,
plotWidth = 2000L,
plotHeight = 1000L,
plotDPI = 150L,
outputDir = NULL,
display = FALSE,
verbose = FALSE,
logs = FALSE,
log_dir = NULL,
log_file = "log_methylationGLM_T1.txt"
)Object returned by prepareMethylationGLM_T1Data().
Integer. TIFF width in pixels when plots are written to disk.
Integer. TIFF height in pixels when plots are written to disk.
Integer. TIFF resolution in DPI when plots are written to disk.
Character or NULL. Directory used for TIFF files. When
NULL, plots are returned in memory only.
Logical. If TRUE, draw plots on the active graphics device.
Logical. If TRUE, emit progress messages with message().
Logical. If TRUE, write the same messages to a log file.
Character or NULL. Directory used for the log file when
logs = TRUE.
Character. File name used when logs = TRUE.
A list with class "dnaEPICO_methylationGLM_T1_distribution_plots"
containing the generated ggplot2 objects and any saved TIFF file paths.
ex <- dnaEPICO:::exampleMethylationGLMStateDnaEpico()
distribution_plots <- plotMethylationGLM_T1Distributions(
preparedData = ex$preparedData,
display = FALSE,
verbose = FALSE,
logs = FALSE
)
names(distribution_plots)
#> [1] "phenotypes" "factors" "covariates" "files"