R/preprocessingMinfiEwasWater_steps.R
plotMetricsMinfiEwasWater.RdPlot multidimensional scaling or density summaries from final metrics
plotMetricsMinfiEwasWater(
metricsData,
targets,
plot = c("mds", "density"),
plotGroupVar = "Sex",
sexColumn = "Sex",
display = FALSE,
file = NULL,
width = 2000L,
height = 1000L,
res = 150L,
verbose = FALSE,
logs = FALSE,
log_dir = NULL,
log_file = "log_plotMetricsMinfiEwasWater.txt"
)Object returned by extractMetricsMinfiEwasWater().
Filtered phenotype data aligned with metricsData.
Character. Plot type: "mds" or "density".
Character. Phenotype column used for the main grouping.
Character. Phenotype column used for the sex grouping in the MDS plot.
Logical. If TRUE, draw the plot on the active graphics
device.
Character or NULL. TIFF file written when supplied.
Integer. TIFF width in pixels when file is supplied.
Integer. TIFF height in pixels when file is supplied.
Integer. TIFF resolution in DPI when file is supplied.
Logical. If TRUE, emit progress messages with message().
Logical. If TRUE, write the same messages to a log file.
Character or NULL. Directory used for the log file when
logs = TRUE.
Character. File name used when logs = TRUE.
Invisibly returns the saved TIFF path when file is supplied,
otherwise NULL.
ex <- dnaEPICO:::exampleMinfiMetricsStateDnaEpico()
plotMetricsMinfiEwasWater(
metricsData = ex$metricsData,
targets = ex$targets,
plot = "density",
plotGroupVar = "Sex",
sexColumn = "Sex",
display = FALSE,
verbose = FALSE,
logs = FALSE
)