R/preprocessingMinfiEwasWater_steps.R
plotRawDensityMinfiEwasWater.RdDraw the pre-normalization beta density plot from a raw minfi object and a grouping variable in the phenotype table.
plotRawDensityMinfiEwasWater(
rawData,
targets,
plotGroupVar = "Sex",
display = FALSE,
file = NULL,
width = 2000L,
height = 1000L,
res = 150L,
verbose = FALSE,
logs = FALSE,
log_dir = NULL,
log_file = "log_plotRawDensityMinfiEwasWater.txt"
)Object returned by buildRawMinfiEwasWater().
Filtered phenotype data aligned with rawData.
Character. Phenotype column used to group samples in the density plot.
Logical. If TRUE, draw the plot on the active graphics
device.
Character or NULL. TIFF file written when supplied.
Integer. TIFF width in pixels when file is supplied.
Integer. TIFF height in pixels when file is supplied.
Integer. TIFF resolution in DPI when file is supplied.
Logical. If TRUE, emit progress messages with message().
Logical. If TRUE, write the same messages to a log file.
Character or NULL. Directory used for the log file when
logs = TRUE.
Character. File name used when logs = TRUE.
Invisibly returns the saved TIFF path when file is supplied,
otherwise NULL.
ex <- dnaEPICO:::exampleMinfiMetricsStateDnaEpico()
plotRawDensityMinfiEwasWater(
rawData = ex$rawData,
targets = ex$targets,
plotGroupVar = "Sex",
display = FALSE,
verbose = FALSE,
logs = FALSE
)